<?php
/**
 * GovernmentMst Entity
 * $Id: GovernmentMst.inc,v 1.1 2020/1/15 11:01:52 Exp $
 * @author lixq
 * @package jp.compass.entity
 * @access public
 */
class GovernmentMst extends CompassDynamicData
{
	var $province;
	var $city;
	var $district;
	var $title;
	var $delete_flg;

	/**
	 * 构造实现。government_mst创建实例。
	 * 
	 * @access public
	 * @param mixed government_mst
	 */
	function constructor($record)
	{
		parent::constructor($record);

		$this->province   = $record["province"];
		$this->city       = $record["city"];
		$this->district   = $record["district"];
		$this->title      = $record["title"];
		$this->delete_flg = $record["delete_flg"];
	}

	/**
	 * 根据条件,获取数据列表。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getList($w_param = null, $orderkey = null, $direction = "ASC", $offset = null, $limit = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}

		return CompassDBHandler::getList("GovernmentMst", "government_mst", $w_param, $orderkey, $direction, $offset, $limit);
	}

	/**
	 * 根据条件，获取数据列表的件数。
	 * 条件与DBManager的doSelect相同。
	 * @access public
	 * @static
	 * @param array 检索条件
	 * @return array Entity的队列
	 */
	public static function getListCount($w_param = null)
	{
		if ($w_param == null) {
			$w_param = array();
			$w_param["delete_flg"] = "false";
		}
		$db = CompassDBManager::getInstance();
		$result = $db->doSelect("government_mst", $w_param, null, null, null, null, "count(*) as count");

		return $result[0]["count"];
	}

	/**
	 * 获得此类指定ID的实例。
	 */
	public static function getById($id)
	{
		// delete_flg
		$param = array();
		$param["delete_flg"] = false;

		return CompassDBHandler::getById("GovernmentMst", "government_mst", $id, $param);
	}

	// -- 这里开始Dynamic ---
	/**
	 * 将此实例写入DB。
	 * DynamicData共用的保存方法。
	 * @access public
	 * @return int 写入实例的ID
	 */
	public function save()
	{
		$v_param = array();

		ParamUtil::copyObj2Array($v_param, $this, "province");
		ParamUtil::copyObj2ArrayNullField($v_param, $this, "city");
		ParamUtil::copyObj2ArrayNullField($v_param, $this, "district");
		ParamUtil::copyObj2Array($v_param, $this, "title");
		ParamUtil::copyObj2Array($v_param, $this, "delete_flg");

		// 保存
		parent::_save("government_mst", $v_param);
	}
}